Optics
======

.. autoclass:: batoid.Optic
    :members:

.. autoclass:: batoid.Interface
    :show-inheritance:
    :members:

.. autoclass:: batoid.Mirror
    :show-inheritance:
    :members:

.. autoclass:: batoid.RefractiveInterface
    :show-inheritance:
    :members:

.. autoclass:: batoid.Baffle
    :show-inheritance:
    :members:

.. autoclass:: batoid.Detector
    :show-inheritance:
    :members:

.. autoclass:: batoid.CompoundOptic
    :show-inheritance:
    :members:

.. autoclass:: batoid.Lens
    :show-inheritance:
    :members:
